@@ -15,7 +15,14 @@ environ = {
     }
 }
 
+try:
+    import tiddlywebplugins.tiddlyspace
+    tiddlyspace = True
+except ImportError:
+    tiddlyspace = False
 
+
+@pytest.mark.skipif('tiddlyspace == False')
 def test_simple_spacelink():
     tiddler = Tiddler('test')
     tiddler.text = '# Hi\nVisit @cdent for more info.'
@@ -34,6 +41,8 @@ def test_escaped_spacelink():
     assert '<a href="http://cdent.tiddlyspace.org:8080/">@cdent</a>' not in output
     assert '@cdent' in output
 
+
+@pytest.mark.skipif('tiddlyspace == False')
 def test_bounded_spacelink():
     tiddler = Tiddler('test')
     tiddler.text = '# Hi\nVisit @cdent: for more info.'
@@ -43,6 +52,8 @@ def test_bounded_spacelink():
     assert ' <a href="http://cdent.tiddlyspace.org:8080/">@cdent</a>' in output
     assert '@cdent' in output
 
+
+@pytest.mark.skipif('tiddlyspace == False')
 def test_spacelink_first():
     tiddler = Tiddler('test')
     tiddler.text = '@cdent for more info.'
@@ -54,6 +65,7 @@ def test_spacelink_first():
     assert '<a href="http://cdent.tiddlyspace.org:8080/">@cdent</a>' in output
 
 
+@pytest.mark.skipif('tiddlyspace == False')
 def test_spacewiki_link():
     tiddler = Tiddler('test')
     tiddler.text = "This is WikiLink@cdent"
@@ -62,6 +74,7 @@ def test_spacewiki_link():
     assert 'This is <a' in output
 
 
+@pytest.mark.skipif('tiddlyspace == False')
 def test_spacewiki_first():
     tiddler = Tiddler('test')
     tiddler.text = "WikiLink@cdent"
@@ -69,6 +82,7 @@ def test_spacewiki_first():
     assert '<a href="http://cdent.tiddlyspace.org:8080/WikiLink">WikiLink</a>' in output
 
 
+@pytest.mark.skipif('tiddlyspace == False')
 def test_spacefree_link():
     tiddler = Tiddler('test')
     tiddler.text = "This is [[Free Link]]@cdent"
